==> 3.5.12-core.tar: kdevelop/kdevdesigner/designer/previewframe.h <==
/**********************************************************************
** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses may use this file in accordance with the Qt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef PREVIEWFRAME_H
#define PREVIEWFRAME_H

#include <tqvbox.h>
#include <tqworkspace.h>

#include "previewwidgetimpl.h"

class PreviewWorkspace : public QWorkspace
{
    Q_OBJECT
public:
    PreviewWorkspace( TQWidget* parent = 0, const char* name = 0 )
        : TQWorkspace( parent, name ) {}
    ~PreviewWorkspace() {}

protected:
    void paintEvent( TQPaintEvent* );
};

class PreviewFrame : public QVBox
{
    Q_OBJECT

public:
    PreviewFrame( TQWidget *parent = 0, const char *name = 0 );
    void setPreviewPalette(TQPalette);

private:
    PreviewWidget 	*previewWidget;
};

#endif

==> 3.5.13-core.tar: kdevelop/kdevdesigner/designer/previewframe.h <==
/**********************************************************************
** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
**
** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef PREVIEWFRAME_H
#define PREVIEWFRAME_H

#include <tqvbox.h>
#include <tqworkspace.h>

#include "previewwidgetimpl.h"

class PreviewWorkspace : public TQWorkspace
{
    Q_OBJECT
  TQ_OBJECT
public:
    PreviewWorkspace( TQWidget* parent = 0, const char* name = 0 )
        : TQWorkspace( parent, name ) {}
    ~PreviewWorkspace() {}

protected:
    void paintEvent( TQPaintEvent* );
};

class PreviewFrame : public TQVBox
{
    Q_OBJECT
  TQ_OBJECT

public:
    PreviewFrame( TQWidget *parent = 0, const char *name = 0 );
    void setPreviewPalette(TQPalette);

private:
    PreviewWidget 	*previewWidget;
};

#endif
